==> qmmp_1.1.4.orig.tar.bz2: qmmp-1.1.4/src/plugins/Input/mad/translations/mad_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>DecoderMADFactory</name>
    <message>
        <location filename="../decodermadfactory.cpp" line="104"/>
        <source>MPEG Plugin</source>
        <translation>MPEG-Modul</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="107"/>
        <source>MPEG Files</source>
        <translation>MPEG-Dateien</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="259"/>
        <source>About MPEG Audio Plugin</source>
        <translation>Über MPEG-Audiomodul</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="260"/>
        <source>Qmmp MPEG Audio Plugin</source>
        <translation>Qmmp MPEG-Audiomodul</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="261"/>
        <source>Compiled against libmad version:</source>
        <translation>Kompiliert gegen libmad-Version:</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="265"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="266"/>
        <source>Source code based on mq3 and madplay projects</source>
        <translation>Basiert auf Code von den mq3- und madplay-Projekten</translation>
    </message>
</context>
<context>
    <name>MPEGMetaDataModel</name>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="70"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="72"/>
        <source>Bitrate</source>
        <translation>Bitrate</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="72"/>
        <source>kbps</source>
        <translation>KBit/s</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Sample rate</source>
        <translation>Abtastrate</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="78"/>
        <location filename="../mpegmetadatamodel.cpp" line="81"/>
        <location filename="../mpegmetadatamodel.cpp" line="84"/>
        <location filename="../mpegmetadatamodel.cpp" line="87"/>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="90"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="91"/>
        <source>File size</source>
        <translation>Dateigröße</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="93"/>
        <location filename="../mpegmetadatamodel.cpp" line="95"/>
        <source>Protection</source>
        <translation>Geschützt</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="93"/>
        <location filename="../mpegmetadatamodel.cpp" line="97"/>
        <location filename="../mpegmetadatamodel.cpp" line="101"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="95"/>
        <location filename="../mpegmetadatamodel.cpp" line="99"/>
        <location filename="../mpegmetadatamodel.cpp" line="103"/>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="97"/>
        <location filename="../mpegmetadatamodel.cpp" line="99"/>
        <source>Copyright</source>
        <translation>Copyright</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="101"/>
        <location filename="../mpegmetadatamodel.cpp" line="103"/>
        <source>Original</source>
        <translation>Original</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPEG Plugin Settings</source>
        <translation>Einstellungen MPEG-Modul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Tag Priority</source>
        <translation>Schlagwortpriorität</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>First:</source>
        <translation>Erster:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <location filename="../settingsdialog.ui" line="110"/>
        <location filename="../settingsdialog.ui" line="159"/>
        <source>ID3v1</source>
        <translation>ID3v1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="66"/>
        <location filename="../settingsdialog.ui" line="115"/>
        <location filename="../settingsdialog.ui" line="164"/>
        <source>ID3v2</source>
        <translation>ID3v2</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <location filename="../settingsdialog.ui" line="120"/>
        <location filename="../settingsdialog.ui" line="169"/>
        <source>APE</source>
        <translation>APE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <location filename="../settingsdialog.ui" line="125"/>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Disabled</source>
        <translation>Deaktiviert</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>Second:</source>
        <translation>Zweiter:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>Third:</source>
        <translation>Dritter:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="198"/>
        <source>Encodings</source>
        <translation>Kodierungen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="210"/>
        <source>ID3v1 encoding:</source>
        <translation>ID3v1-Kodierung:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="236"/>
        <source>ID3v2 encoding:</source>
        <translation>ID3v2-Kodierung:</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Input/mad/translations/mad_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>DecoderMADFactory</name>
    <message>
        <location filename="../decodermadfactory.cpp" line="116"/>
        <source>MPEG Plugin</source>
        <translation>MPEG-Modul</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="119"/>
        <source>MPEG Files</source>
        <translation>MPEG-Dateien</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="271"/>
        <source>About MPEG Audio Plugin</source>
        <translation>Über MPEG-Audiomodul</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="272"/>
        <source>Qmmp MPEG Audio Plugin</source>
        <translation>Qmmp MPEG-Audiomodul</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="273"/>
        <source>Compiled against libmad version:</source>
        <translation>Kompiliert gegen libmad-Version:</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="277"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="278"/>
        <source>Source code based on mq3 and madplay projects</source>
        <translation>Basiert auf Code von den mq3- und madplay-Projekten</translation>
    </message>
</context>
<context>
    <name>MPEGMetaDataModel</name>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="70"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="72"/>
        <source>Bitrate</source>
        <translation>Bitrate</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="72"/>
        <source>kbps</source>
        <translation>KBit/s</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Sample rate</source>
        <translation>Abtastrate</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="78"/>
        <location filename="../mpegmetadatamodel.cpp" line="81"/>
        <location filename="../mpegmetadatamodel.cpp" line="84"/>
        <location filename="../mpegmetadatamodel.cpp" line="87"/>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="90"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="91"/>
        <source>File size</source>
        <translation>Dateigröße</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="93"/>
        <location filename="../mpegmetadatamodel.cpp" line="95"/>
        <source>Protection</source>
        <translation>Geschützt</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="93"/>
        <location filename="../mpegmetadatamodel.cpp" line="97"/>
        <location filename="../mpegmetadatamodel.cpp" line="101"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="95"/>
        <location filename="../mpegmetadatamodel.cpp" line="99"/>
        <location filename="../mpegmetadatamodel.cpp" line="103"/>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="97"/>
        <location filename="../mpegmetadatamodel.cpp" line="99"/>
        <source>Copyright</source>
        <translation>Copyright</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="101"/>
        <location filename="../mpegmetadatamodel.cpp" line="103"/>
        <source>Original</source>
        <translation>Original</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPEG Plugin Settings</source>
        <translation>Einstellungen MPEG-Modul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Tag Priority</source>
        <translation>Schlagwortpriorität</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>First:</source>
        <translation>Erster:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <location filename="../settingsdialog.ui" line="110"/>
        <location filename="../settingsdialog.ui" line="159"/>
        <source>ID3v1</source>
        <translation>ID3v1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="66"/>
        <location filename="../settingsdialog.ui" line="115"/>
        <location filename="../settingsdialog.ui" line="164"/>
        <source>ID3v2</source>
        <translation>ID3v2</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <location filename="../settingsdialog.ui" line="120"/>
        <location filename="../settingsdialog.ui" line="169"/>
        <source>APE</source>
        <translation>APE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <location filename="../settingsdialog.ui" line="125"/>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Disabled</source>
        <translation>Deaktiviert</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>Second:</source>
        <translation>Zweiter:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>Third:</source>
        <translation>Dritter:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="198"/>
        <source>Encodings</source>
        <translation>Kodierungen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="210"/>
        <source>ID3v1 encoding:</source>
        <translation>ID3v1-Kodierung:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="236"/>
        <source>ID3v2 encoding:</source>
        <translation>ID3v2-Kodierung:</translation>
    </message>
</context>
</TS>
